Hello Hrvoje!
The comment above `savehist-coding-system' says it prefers utf-8, this
patch lets savehist use utf-8 even in XEmacs 21.4 providing utf-8 is
present in the coding system list.
edit-utils patch:
ChangeLog files diff command: cvs -q diff -U 0
Files affected: ChangeLog
Source files diff command: cvs -q diff -uN
Files affected: savehist.el
Index: ChangeLog
===================================================================
RCS file: /pack/xemacscvs/XEmacs/packages/xemacs-packages/edit-utils/ChangeLog,v
retrieving revision 1.216
diff -u -p -U0 -r1.216 ChangeLog
--- ChangeLog 5 Dec 2005 06:19:11 -0000 1.216
+++ ChangeLog 19 Dec 2005 04:22:52 -0000
@@ -0,0 +1,5 @@
+2005-12-19 Steve Youngs <steve(a)sxemacs.org>
+
+ * savehist.el (savehist-coding-system): Use utf-8 even in XEmacs
+ 21.4 providing it is in coding system list.
+
Index: savehist.el
===================================================================
RCS file: /pack/xemacscvs/XEmacs/packages/xemacs-packages/edit-utils/savehist.el,v
retrieving revision 1.4
diff -u -p -u -r1.4 savehist.el
--- savehist.el 14 Nov 2005 07:05:54 -0000 1.4
+++ savehist.el 19 Dec 2005 04:22:37 -0000
@@ -135,12 +135,12 @@ save."
;; This should be capable of representing characters used by Emacs.
;; We prefer UTF-8 over ISO 2022 because it is well-known outside
;; Mule. XEmacs prir to 21.5 had UTF-8 provided by an external
;; package which may not be loaded, which is why we check for version.
(defvar savehist-coding-system (if (and (featurep 'xemacs)
- (<= emacs-major-version 21)
- (< emacs-minor-version 5))
- 'iso-2022-8 'utf-8)
+ (member 'utf-8 (coding-system-list)))
+ 'utf-8 'iso-2022-8)
"The coding system savehist uses for saving the minibuffer history.
Changing this value while Emacs is running is supported, but considered
unwise, unless you know what you are doing.")
@@ -135,12 +135,12 @@ save."
;; This should be capable of representing characters used by Emacs.
;; We prefer UTF-8 over ISO 2022 because it is well-known outside
-;; Mule. XEmacs prir to 21.5 had UTF-8 provided by an external
-;; package which may not be loaded, which is why we check for version.
+;; Mule. XEmacs prior to 21.5 had UTF-8 provided by an external
+;; package which may not be loaded, which is why we check
+;; coding-system-list.
(defvar savehist-coding-system (if (and (featurep 'xemacs)
--
|---<Steve Youngs>---------------<GnuPG KeyID: A94B3003>---|
| I am Dyslexic of Borg. |
| Fusistance is retile. Your arse will be laminated. |
|------------------------------------<steve(a)sxemacs.org>---|